class CausesController < ApplicationController
  layout 'painel'

  before_filter :require_login
  before_action :set_causer, only: [:destroy]
  before_action :set_incident, only: [:new, :destroy]

  # GET /cause
  def new
    @cause = Cause.new
    @incidents = Incident.filter(filter_params)
  end

  # POST /cause/1
  def create
    @incident = Incident.find(cause_params[:incident_id])
    @causer = Incident.find(cause_params[:causer_id])

    if is_already_caused_by?(@incident, @causer)
      flash[:warning] = "Incidente já está listado como causa!"
    elsif @incident.id == @causer.id
      flash[:warning] = "Incidente não pode ser causado por ele mesmo!"
    else
      @cause = Cause.new(cause_params)

      if @cause.save
        flash[:success] = 'Causa foi adicionada.'
      else
        render :new
      end
    end

    redirect_to @incident
  end

  # POST /cause/1
  def destroy
    @cause = Cause.find_by(incident_id: @incident.id, causer_id: @causer.id)

    if @cause.destroy
      flash[:success] = 'Causa foi removida.'
    end

    redirect_to :back
  end

  protected

  def is_already_caused_by?(incident, causer)
    if Cause.where(incident_id: incident.id, causer_id: causer.id).first
      return true
    else
      return false
    end
  end

  private

  def set_incident
    @incident = Incident.find(params[:incident_id])
  end

  def set_causer
    @causer = Incident.find(params[:causer_id])
  end

  def cause_params
    params.require(:cause).permit(:incident_id, :causer_id)
  end

  def filter_params
    params.slice(:has_number, :is_assigned_to, :belongs_to_team, :created_since)
  end

end
