class CisController < ApplicationController
  layout 'painel'

  before_action :set_ci, only: [:show, :edit, :update, :destroy]
  before_filter :require_login
  before_filter :require_manager, only: [ :new, :create, :update, :edit ]
  before_filter :require_admin, only: :destroy
  before_action :disable_form, only: [:show]
  before_action :enable_form, except: [:show]

  autocomplete :team, :name, full: true

  # GET /cis
  def index
    if params.has_key?(:name)
      @cis = Ci.where('name ilike ?', "%#{ params[:name] }%")
    else
      @cis = Ci.all
    end
  end

  # GET /cis/1
  def show
  end

  # GET /cis/new
  def new
    @ci = Ci.new
  end

  # GET /cis/1/edit
  def edit
  end

  # POST /cis
  def create
    @ci = Ci.new(ci_params)

    respond_to do |format|
      if @ci.save
        format.html do
          flash[:success] = 'O item de configuração foi criado.'
          redirect_to @ci
        end
      else
        format.html { render :new }
      end
    end
  end

  # PATCH/PUT /cis/1
  def update
    respond_to do |format|
      if @ci.update(ci_params)
        format.html do
          flash[:success] = 'O item de configuração foi atualizado.'
          redirect_to @ci
        end
      else
        format.html { render :edit }
      end
    end
  end

  # DELETE /cis/1
  def destroy
    @ci.destroy

    respond_to do |format|
      format.html do
        flash[:success] = 'O ítem de configuração foi removido.'
        redirect_to cis_url
      end
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_ci
      @ci = Ci.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def ci_params
      params[:ci].permit!
    end
end
