class ClosingCategoriesController < ApplicationController
  layout 'painel'

  before_action :set_closing_category, only: [:show, :edit, :update, :destroy]
  before_filter :require_login
  before_filter :require_admin
  before_action :disable_form, only: [:show]
  before_action :enable_form, except: [:show]

  # GET /closing_categories
  def index
    if params.has_key?(:name)
      @closing_categories = ClosingCategory.where('name ilike ?', "%#{ params[:name] }%")
    else
      @closing_categories = ClosingCategory.all
    end
  end

  # GET /closing_categories/1
  def show
  end

  # GET /closing_categories/new
  def new
    @closing_category = ClosingCategory.new
  end

  # GET /closing_categories/1/edit
  def edit
  end

  # POST /closing_categories
  def create
    @closing_category = ClosingCategory.new(closing_category_params)

    respond_to do |format|
      if @closing_category.save
        format.html do
          flash[:success] = 'A categoria foi criada.'
          redirect_to @closing_category
        end
      else
        format.html { render :new }
      end
    end
  end

  # PATCH/PUT /closing_categories/1
  def update
    respond_to do |format|
      if @closing_category.update(closing_category_params)
        format.html do
          flash[:success] = 'A categoria foi atualizada.'
          redirect_to @closing_category
        end
      else
        format.html { render :edit }
      end
    end
  end

  # DELETE /closing_categories/1
  def destroy
    @closing_category.destroy
    respond_to do |format|
      format.html do
        flash[:success] = 'A categoria foi removida.'
        redirect_to closing_categories_url
      end
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_closing_category
      @closing_category = ClosingCategory.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def closing_category_params
      params[:closing_category].permit!
    end
end
