class DashboardsController < ApplicationController
  layout 'painel'

  before_filter :require_login

  def index
    @incidents_assignee = build_incidents_by_assignee
    @incidents_requester = build_incidents_by_requester
    @incidents_agent = build_incidents_by_agent
    @incidents_teams = build_incidents_by_teams
    build_chart
  end

  private

  def build_incidents_by_assignee
    Incident.where("assignee_id = #{current_user} AND state_id IN (#{State.open.id}, #{State.in_progress.id})")
  end

  def build_incidents_by_requester
    Incident.where("requester_id = #{current_user} AND state_id IN (#{State.open.id}, #{State.in_progress.id})")
  end

  def build_incidents_by_agent
    Incident.where("agent_id = #{current_user} AND state_id IN (#{State.open.id}, #{State.in_progress.id})")
  end

  def build_incidents_by_teams
    list = []
    user = User.find(current_user)

    user.teams.each do |team|
      list << team.id
    end

    if list.length > 0
      Incident.where("team_id IN (#{list.map(&:inspect).join(', ')}) AND state_id IN (#{State.open.id})")
    else
      Incident.none
    end
  end

  def build_chart
    @chart = LazyHighCharts::HighChart.new('graph') do |f|
      f.xAxis(categories: ['Responsável', 'Requisitante', 'Agente', 'Equipes'])
      f.series(name: 'Incidentes Ativos', yAxis: 0, data: [
        @incidents_assignee.length,
        @incidents_requester.length,
        @incidents_agent.length,
        @incidents_teams.length
      ])

      f.chart( { defaultSeriesType: 'bar' })
    end
  end
end
