class IncidentsController < ApplicationController
  layout 'painel'

  before_action :set_incident, only: [:show, :edit, :update, :destroy]
  before_filter :require_login
  before_filter :require_agent, only: [ :new, :create ]
  before_filter :require_admin, only: [ :destroy ]
  before_action :disable_form, only: [:show]
  before_action :enable_form, except: [:show]

  autocomplete :user, :name, full: true
  autocomplete :team, :name, full: true

  # GET /incidents
  def index
    @incidents = Incident.filter(filter_params)
  end

  # GET /incidents/1
  def show
  end

  # GET /incidents/new
  def new
    @incident = Incident.new
  end

  # GET /incidents/1/edit
  def edit
    unless is_user_admin? || is_user_manager?
      require_incident_ownership
    end
  end

  # POST /incidents
  def create
    @incident = Incident.new(incident_params)

    if @incident.save
      flash[:success] = 'O incidente foi criado.'
      redirect_to @incident
    else
      render :new
    end
  end

  # PATCH/PUT /incidents/1
  def update
    unless is_user_admin? || is_user_manager?
      require_incident_ownership
    end

    if @incident.update(incident_params)
      flash[:success] = 'O incidente foi atualizado.'
      redirect_to @incident
    else
      render :edit
    end
  end

  # DELETE /incidents/1
  def destroy
    @incident.destroy
    flash[:success] = 'O incidente foi removido.'
    redirect_to @incident
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_incident
      @incident = Incident.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def incident_params
      params[:incident].permit!
    end

    def filter_params
      params.slice(:has_number, :is_assigned_to, :belongs_to_team, :created_since)
    end

    def require_incident_ownership
      unless is_user_agent? && @incident.agent.id == current_user
        unless @incident.assignee != nil && @incident.assignee.id == current_user
          redirect_to :back, flash: { warning: "Você não possui acesso a este recurso" }
        end
      end
    end
end
