class MembershipsController < ApplicationController
  layout 'painel'

  before_action :set_user, only: [:destroy]
  before_action :set_team, only: [:new, :destroy]
  before_filter :require_login

  # GET /membership
  def new
    @membership =  Membership.new

    if search_params.has_key?(:search)
      @users = User.where('name ilike ?', "%#{ search_params[:search] }%")
    else
      @users = User.all
    end
  end

  # POST /membership/1
  def create
    @team = Team.find(membership_params[:team_id])
    @user = User.find(membership_params[:user_id])

    if is_already_member?(@user, @team)
      flash[:warning] = "Usuário já faz parte do grupo!"
      redirect_to @team
    else
      @membership = Membership.new(membership_params)

      if @membership.save
        flash[:success] = 'Usuário foi adicionado à equipe.'
        redirect_to @team
      else
        render :new
      end
    end
  end

  # POST /membership/1
  def destroy
    @membership = Membership.find_by(user_id: @user.id, team_id: @team.id)

    if @membership.destroy
      flash[:success] = 'Usuário foi removido do time.'
    end

    redirect_to :back
  end

  protected

  def is_already_member?(user, team)
    if Membership.where(team_id: team.id, user_id: user.id).first
      return true
    else
      return false
    end
  end

  private

  def set_team
    @team = Team.find(params[:team_id])
  end

  def set_user
    @user = User.find(params[:user_id])
  end

  def membership_params
    params.require(:membership).permit(:team_id, :user_id, :is_manager, :is_alerted)
  end

  def search_params
    params.permit(:search)
  end
end
