class OpeningCategoriesController < ApplicationController
  layout 'painel'

  before_action :set_opening_category, only: [:show, :edit, :update, :destroy]
  before_filter :require_login
  before_filter :require_admin
  before_action :disable_form, only: [:show]
  before_action :enable_form, except: [:show]

  # GET /opening_categories
  def index
    if params.has_key?(:name)
      @opening_categories = OpeningCategory.where('name ilike ?', "%#{ params[:name] }%")
    else
      @opening_categories = OpeningCategory.all
    end
  end

  # GET /opening_categories/1
  def show
  end

  # GET /opening_categories/new
  def new
    @opening_category = OpeningCategory.new
  end

  # GET /opening_categories/1/edit
  def edit
  end

  # POST /opening_categories
  def create
    @opening_category = OpeningCategory.new(opening_category_params)

    respond_to do |format|
      if @opening_category.save
        format.html do
          flash[:success] = 'A categoria foi criada.'
          redirect_to @opening_category
        end
      else
        format.html { render :new }
      end
    end
  end

  # PATCH/PUT /opening_categories/1
  def update
    respond_to do |format|
      if @opening_category.update(opening_category_params)
        format.html do
          flash[:success] = 'A categoria foi atualizada.'
          redirect_to @opening_category
        end
      else
        format.html { render :edit }
      end
    end
  end

  # DELETE /opening_categories/1
  def destroy
    @opening_category.destroy
    respond_to do |format|
      format.html do
        flash[:success] = 'A categoria foi removida.'
        redirect_to opening_categories_url
      end
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_opening_category
      @opening_category = OpeningCategory.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def opening_category_params
      params[:opening_category].permit!
    end
end
