class RelationshipsController < ApplicationController
  layout 'painel'

  before_action :set_relater, only: [:destroy]
  before_action :set_ci, only: [:new, :destroy]
  before_filter :require_login

  # GET /relationship
  def new
    @relationship =  Relationship.new

    if search_params.has_key?(:search)
      @cis = Ci.where('name ilike ?', "%#{ search_params[:search] }%")
    else
      @cis = Ci.all
    end
  end

  # POST /relationship/1
  def create
    @ci = Ci.find(relationship_params[:ci_id])
    @relater = Ci.find(relationship_params[:relater_id])

    if is_already_related?(@ci, @relater)
      flash[:warning] = "Item de Configuração já possui este relacionamento!"
      redirect_to @ci
    else
      @relationship = Relationship.new(relationship_params)

      if @relationship.save
        flash[:success] = 'Relacionamento foi criado.'
        redirect_to @ci
      else
        render :new
      end
    end
  end

  # POST /relationship/1
  def destroy
    @relationship = Relationship.find_by(ci_id: @ci.id, relater_id: @relater.id)

    if @relationship.destroy
      flash[:success] = 'Relacionamento foi removido.'
    end

    redirect_to :back
  end

  protected

  def is_already_related?(ci, relater)
    if Relationship.where(ci_id: ci.id, relater_id: relater.id).first
      return true
    else
      return false
    end
  end

  private

  def set_ci
    @ci = Ci.find(params[:ci_id])
  end

  def set_relater
    @relater = Ci.find(params[:relater_id])
  end

  def relationship_params
    params.require(:relationship).permit(:ci_id, :relater_id, :relation_id)
  end

  def search_params
    params.permit(:search)
  end
end
