class ReportsController < ApplicationController
  layout 'painel'

  before_filter :require_login
  before_filter :require_manager, only: :index

  # GET /reports
  def index
    case reports_params[:name]
    when 'impact'
      @chart = build_impact_chart
    when 'incident'
      @chart = build_incident_chart
    end
  end

  private

  def reports_params
    params.permit(:name)
  end

  def build_impact_chart
    @chart = LazyHighCharts::HighChart.new('graph') do |f|
      f.title(text: 'Itens de Configuração Mais Impactados')

      start_date = Date.today - 12.months
      end_date = Date.today

      f.xAxis(categories: xaxis(Date.today))

      Ci.all.each do |ci|
        current_date = start_date
        chart_data = []

        while current_date <= end_date
          chart_data << Affect.where(ci_id: ci.id, created_at: current_date.beginning_of_month..(current_date.end_of_month + 1.day)).count
          current_date += 1.month
        end

        f.series(name: ci.name, data: chart_data)
      end

      f.chart({ defaultSeriesType: 'line' })
    end
  end

  def build_incident_chart
    @chart = LazyHighCharts::HighChart.new('graph') do |f|
      f.title(text: 'Números de Incidents Criados')

      start_date = Date.today - 12.months
      end_date = Date.today
      current_date = start_date
      chart_data = []

      f.xAxis(categories: xaxis(Date.today))

      while current_date <= end_date
        chart_data << Incident.where(created_at: current_date.beginning_of_month..(current_date.end_of_month + 1.day)).count
        current_date += 1.month
      end

      f.series(name: 'Incidentes', data: chart_data)
      f.chart({ defaultSeriesType: 'line' })
    end
  end

  def xaxis(start_date)
    current_date = start_date - 12.month
    end_date = start_date
    categories = []

    while current_date < end_date
      categories << I18n.t('date.abbr_month_names')[current_date.month] + '/' + current_date.strftime('%y')
      current_date += 1.month
    end

    categories
  end
end
