class RolesController < ApplicationController
  layout 'painel'

  before_action :set_profile, only: :destroy
  before_action :set_user, only: [:new, :destroy]
  before_action :number_of_roles, only: :destroy
  before_filter :require_login

  # GET /profile
  def new
    @role = Role.new
    @profiles = Profile.all
  end

  # POST /profile/1
  def create
    @user = User.find(role_params[:user_id])
    @profile = Profile.find(role_params[:profile_id])

    if is_already_enrolled?(@user, @profile)
      flash[:warning] = "Usuário já possui este perfil!"
      redirect_to user_path(@user)
    else
      @role = Role.new(role_params)

      if @role.save
        flash[:success] = 'Perfil foi adicionado.'
        redirect_to user_path(@user)
      else
        render :new
      end
    end
  end

  # DELETE /profile/1
  def destroy
    @role = Role.find_by(user_id: @user.id, profile_id: @profile.id)

    if @role.destroy
      flash[:success] = 'Perfil foi removido.'
    end

    redirect_to user_path(@user)
  end

  protected

  def set_profile
    @profile = Profile.find(params[:profile_id])
  end

  def set_user
    @user = User.find(params[:user_id])
  end

  def role_params
    params[:role].permit(:user_id, :profile_id)
  end

  private

  def is_already_enrolled?(user, profile)
    return true if Role.find_by(user_id: @user.id, profile_id: @profile.id)
    false
  end

  def number_of_roles
    roles = Role.where(user_id: @user.id)
    if roles && roles.count <= 1
      flash[:warning] = 'Usuário precisa ter pelo menos um perfil'
      redirect_to :back
    end
  end
end
