class TeamsController < ApplicationController
  layout 'painel'

  before_action :set_team, only: [:show, :edit, :update, :destroy]
  before_filter :require_login
  before_filter :require_manager, only: [ :new, :create, :update, :edit ]
  before_filter :require_admin, only: :destroy
  before_action :disable_form, only: [:show]
  before_action :enable_form, except: [:show]

  # GET /teams
  def index
    if params.has_key?(:name)
      @teams = Team.where('name ilike ?', "%#{ params[:name] }%")
    else
      @teams = Team.all
    end
  end

  # GET /teams/1
  def show
  end

  # GET /teams/new
  def new
    @team = Team.new
  end

  # GET /teams/1/edit
  def edit
  end

  # POST /teams
  def create
    @team = Team.new(team_params)

    respond_to do |format|
      if @team.save
        format.html do
          flash[:success] = 'A equipe foi criada.'
          redirect_to @team
        end
      else
        format.html { render :new }
      end
    end
  end

  # PATCH/PUT /teams/1
  def update
    respond_to do |format|
      if @team.update(team_params)
        format.html do
          flash[:success] = 'A equipe foi atualizada.'
          redirect_to @team
        end
      else
        format.html { render :edit }
      end
    end
  end

  # DELETE /teams/1
  def destroy
    @team.destroy
    respond_to do |format|
      format.html do
        flash[:success] = 'A equipe foi removida.'
        redirect_to teams_url
      end
    end
  end

  private

  def set_team
    @team = Team.find(params[:id])
  end

  def team_params
    params[:team].permit!
  end
end
