class UsersController < ApplicationController
  layout 'painel'

  before_filter :require_login
  before_filter :require_manager, only: [ :new, :create ]
  before_filter :require_admin, only: :destroy
  before_action :set_user, only: [:show, :edit, :update, :destroy]
  before_action :disable_form, only: [:show]
  before_action :enable_form, except: [:show]

  # GET /users
  def index
    if params.has_key?(:name)
      @users = User.where('name ilike ?', "%#{ params[:name] }%")
    else
      @users = User.all
    end
  end

  # GET /users/1
  def show
  end

  # GET /users/new
  def new
    @user = User.new
  end

  # GET /users/1/edit
  def edit
  end

  # POST /users
  def create
    @user = User.new(user_params)

    respond_to do |format|
      if @user.save
        format.html do
          flash[:success] = 'O usuário foi criado.'
          redirect_to @user
        end
      else
        format.html { render :new }
      end
    end
  end

  # PATCH/PUT /users/1
  def update
    unless is_user_admin? || is_user_manager?
      require_current_user(@user)
    end

    respond_to do |format|
      if @user.update(user_params)
        format.html do
          flash[:success] = 'O usuário foi atualizado.'
          redirect_to @user
        end
      else
        format.html { render :edit }
      end
    end
  end

  # DELETE /users/1
  def destroy
    @user.destroy
    respond_to do |format|
      format.html do
        flash[:success] = 'O usuário foi removido.'
        redirect_to users_url
      end
    end
  end

  private

  def set_user
    @user = User.find(params[:id])
  end

  def user_params
    params[:user].permit!
  end
end
