module ApplicationHelper
  # ############################################################################
  # LOGIN
  # ############################################################################
  def sign_in(email, password)
    user = User.find_by email: email

    if user && user.authenticate(password)
      session[:user_id] = user.id
      set_user_profile(user)
      return true
    else
      return false
    end
  end

  def sign_out
    session[:user_id] = nil
  end

  def user_signed_in?
    session[:user_id] == nil ? false : true
  end

  def current_user
    session[:user_id]
  end

  # ############################################################################
  # PROFILE
  # ############################################################################

  def current_profile
    session[:profile_id]
  end

  def is_user_admin?
    return false unless current_profile
    profile = Profile.find(current_profile)
    return false unless profile.is_admin
    return true
  end

  def is_user_manager?
    return false unless current_profile
    profile = Profile.find(current_profile)
    return false unless profile.is_manager
    return true
  end

  def is_user_agent?
    return false unless current_profile
    profile = Profile.find(current_profile)
    return false unless profile.is_agent
    return true
  end

  def is_user_analyst?
    return false unless current_profile
    profile = Profile.find(current_profile)
    return false if profile.is_admin || profile.is_manager || profile.is_agent
    return true
  end

  def set_user_profile(user)
    raise "Usuário não possui nenhum perfil" unless user.profiles.length > 0

    profile = user.profiles.where(is_admin: true).first
    return session[:profile_id] = profile.id if profile

    profile = user.profiles.where(is_manager: true).first
    return session[:profile_id] = profile.id if profile

    profile = user.profiles.where(is_agent: true).first
    return session[:profile_id] = profile.id if profile

    profile = user.profiles.first
    return session[:profile_id] = profile.id if profile
  end

  # ############################################################################
  # RESOURCE ACCESS
  # ############################################################################

  def require_login
    unless user_signed_in?
      redirect_to login_path, flash: { warning: 'Você precisa estar logado.' }
    end
  end

  def require_admin
    unless is_user_admin?
      redirect_to :back, flash: { warning: "Você não possui acesso a este recurso" }
    end
  end

  def require_manager
    unless is_user_admin? || is_user_manager?
      redirect_to :back, flash: { warning: "Você não possui acesso a este recurso" }
    end
  end

  def require_agent
    unless is_user_admin? || is_user_manager? || is_user_agent?
      redirect_to :back, flash: { warning: "Você não possui acesso a este recurso" }
    end
  end

  def require_current_user(user)
    unless user.id == current_user
      redirect_to :back, flash: { warning: "Você não possui acesso a este recurso" }
    end
  end

  # ############################################################################
  # FORMS
  # ############################################################################

  def disable_form
    @is_form_disabled = true
  end

  def enable_form
    @is_form_disabled = false
  end

  # ############################################################################
  # INCIDENTS
  # ############################################################################

  def incident_number(incident)
    "#{INCIDENT_PREFIX}#{incident.id.to_s.rjust(6, '0')}"
  end

  # ############################################################################
  # MISC
  # ############################################################################

  def is_current_controller?(controller)
    controller == params[:controller]
  end
end
