class User < ActiveRecord::Base
  before_create :add_default_role

  has_many :memberships
  has_many :teams, through: :memberships
  has_many :requests, :class_name => 'Incident', :foreign_key => 'requester_id'
  has_many :assignments, :class_name => 'Incident', :foreign_key => 'assignee_id'
  has_many :incidents, :class_name => 'Incident', :foreign_key => 'agent_id'
  has_many :logs
  has_many :roles
  has_many :profiles, through: :roles

  has_secure_password

  validates :name, presence: true
  validates :email, presence: true, uniqueness: true, format: { with: /\A([\w+\-].?)+@[a-z\d\-]+(\.[a-z]+)*\.[a-z]+\z/i }
  validates :password, presence: true, confirmation: true, on: [:create, :update], if: :password_digest_changed?
  validates :telephone, format: { with: /\A\+?\d{2}? ?\(\d{2}\) ?\d{4}-\d{4}\z/ }, if: :telephone?
  validates :mobile, format: { with: /\A\+?\d{2}? ?\(\d{2}\) ?\d{4,5}-\d{4}\z/ }, if: :mobile?
  validates :postcode, format: { with: /\A\d{5}-\d{3}\z/ }, if: :postcode?

  private

  def add_default_role
    default_profile = Profile.find_by(name: 'Usuário')
    role = self.roles.build(profile_id: default_profile.id)
    true
  end
end
