require 'test_helper'

class UserIntegrationTest < ActionDispatch::IntegrationTest
  def setup
    @user = create(:user)
  end

  def teardown
  end

  test 'register a new user' do
    new_user = build(:user)
    user_login(@user.email, @user.password)

    within('#menuAdmin') do
      click_link('Usuários')
    end

    click_link('Novo')

    within('#new_user') do
      fill_in 'user_name', with: new_user.name
      fill_in 'user_email', with: new_user.email
      fill_in 'user_password', with: new_user.password
      fill_in 'user_password_confirmation', with: new_user.password
    end

    click_on('Salvar')
    assert page.has_content?('O usuário foi criado.'), 'Success message not found'
  end

  test 'search an user' do
    user_login(@user.email, @user.password)

    within('#menuAdmin') do
      click_link('Usuários')
    end

    within('.form-inline') do
      fill_in 'name', with: @user.name
    end

    click_button('button_filter')
    assert page.has_content?(@user.email), 'User not found'
  end

  test 'edit an user' do
    user_login(@user.email, @user.password)

    within('#menuAdmin') do
      click_link('Usuários')
    end

    click_link(@user.name)
    visit(edit_user_path(@user))

    within("#edit_user_#{@user.id}") do
      fill_in 'user_name', with: "#{@user.name} EDITED"
    end

    click_on('Salvar')
    assert page.has_content?('O usuário foi atualizado.'), 'Success message not found'
    click_on('Cancelar')
    assert page.has_content?("#{@user.name} EDITED"), 'Edited user not found'
  end

  test 'remove an user' do
    user_login(@user.email, @user.password)

    within('#menuAdmin') do
      click_link('Usuários')
    end

    click_link(@user.name)
    click_link('Remover')
    assert page.has_content?('O usuário foi removido.'), 'Success message not found'
    visit(users_path)
    assert_not page.has_content?(@user.email), 'User is still being shown'
  end
end
