require 'test_helper'

class UserTest < ActiveSupport::TestCase
  def setup
    @user = create(:user)
  end

  def teardown
  end

  should validate_presence_of(:name)
  should have_secure_password
  should allow_value('(11) 9999-9999').for(:telephone)
  should allow_value('(11) 99999-9999', '(11) 9999-9999').for(:mobile)
  should allow_value('99999-999').for(:postcode)

  should_not allow_value('(11) 99999-9999', '(11)9999-9999', '1199999999', '11 9999-9999').for(:telephone)
  should_not allow_value('(11)9999-9999', '1199999999', '11999999999', '11 9999-9999', '11 99999-9999').for(:mobile)
  should_not allow_value('99999999', '9999-999', '99999-99').for(:postcode)

  test 'should update user' do
    assert @user.update({
      address: Faker::Address.street_name,
      number: Faker::Address.secondary_address,
      village: Faker::Address.city,
      city: Faker::Address.city,
      state: Faker::Address.state,
      postcode: '99999-999'
    }), 'user was not updated'
  end

  test 'should remove user' do
    assert @user.destroy, 'user was not removed'
  end

  test 'should enable user' do
    assert @user.update_attribute(:active, true), 'user was not enabled'
  end

  test 'should disable user' do
    assert @user.update_attribute(:active, false), 'user was not disabled'
  end
end
